From 86d8364ac704bdc8ad2dfcf52307d9626cfac567 Mon Sep 17 00:00:00 2001
From: Timothy Pearson <kb9vqf@pearsoncomputing.net>
Date: Fri, 25 Jan 2013 00:37:21 -0600
Subject: Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid
 conflicts with KDE4

---
 kioslaves/sieve/sieve.cpp | 30 +++++++++++++++---------------
 1 file changed, 15 insertions(+), 15 deletions(-)

(limited to 'kioslaves/sieve/sieve.cpp')

diff --git a/kioslaves/sieve/sieve.cpp b/kioslaves/sieve/sieve.cpp
index 4e95c5a16..9d373c2ad 100644
--- a/kioslaves/sieve/sieve.cpp
+++ b/kioslaves/sieve/sieve.cpp
@@ -77,7 +77,7 @@ static sasl_callback_t callbacks[] = {
 
 static const unsigned int SIEVE_DEFAULT_RECIEVE_BUFFER = 512;
 
-using namespace KIO;
+using namespace TDEIO;
 extern "C"
 {
 	KDE_EXPORT int kdemain(int argc, char **argv)
@@ -441,7 +441,7 @@ void kio_sieveProtocol::disconnect(bool forcibly)
 
 		// This crashes under certain conditions as described in
 		// http://intevation.de/roundup/kolab/issue2442
 		// Fixing KIO::TCPSlaveBase::atEnd() for !fd would also work but 3.x is on life support.
 		//if (!operationSuccessful())
 		//	ksDebug() << "Server did not logout cleanly." << endl;
 	}
@@ -745,7 +745,7 @@ void kio_sieveProtocol::get(const KURL& url)
 		do {
 		  // wait for data...
 		  if ( !waitForResponse( 600 ) ) {
-		    error( KIO::ERR_SERVER_TIMEOUT, m_sServer );
+		    error( TDEIO::ERR_SERVER_TIMEOUT, m_sServer );
 		    disconnect( true );
 		    return;
 		  }
@@ -757,7 +757,7 @@ void kio_sieveProtocol::get(const KURL& url)
 		  ssize_t this_recv_len = read( dat.data(), dat.size() );
 
 		  if ( this_recv_len < 1 && !isConnectionValid() ) {
-		    error( KIO::ERR_CONNECTION_BROKEN, m_sServer );
+		    error( TDEIO::ERR_CONNECTION_BROKEN, m_sServer );
 		    disconnect( true );
 		    return;
 		  }
@@ -856,15 +856,15 @@ void kio_sieveProtocol::stat(const KURL& url)
 
 	if (filename.isEmpty()) {
 		UDSAtom atom;
-		atom.m_uds = KIO::UDS_NAME;
+		atom.m_uds = TDEIO::UDS_NAME;
 		atom.m_str = "/";
 		entry.append(atom);
 
-		atom.m_uds = KIO::UDS_FILE_TYPE;
+		atom.m_uds = TDEIO::UDS_FILE_TYPE;
 		atom.m_long = S_IFDIR;
 		entry.append(atom);
 
-		atom.m_uds = KIO::UDS_ACCESS;
+		atom.m_uds = TDEIO::UDS_ACCESS;
 		atom.m_long = 0700;
 		entry.append(atom);
 
@@ -885,22 +885,22 @@ void kio_sieveProtocol::stat(const KURL& url)
 					entry.clear();
 
 					UDSAtom atom;
-					atom.m_uds = KIO::UDS_NAME;
+					atom.m_uds = TDEIO::UDS_NAME;
 					atom.m_str = TQString::fromUtf8(r.getKey());
 					entry.append(atom);
 
-					atom.m_uds = KIO::UDS_FILE_TYPE;
+					atom.m_uds = TDEIO::UDS_FILE_TYPE;
 					atom.m_long = S_IFREG;
 					entry.append(atom);
 
-					atom.m_uds = KIO::UDS_ACCESS;
+					atom.m_uds = TDEIO::UDS_ACCESS;
 					if ( r.getExtra() == "ACTIVE" )
 					  atom.m_long = 0700; // mark exec'able
 					else
 					  atom.m_long = 0600;
 					entry.append(atom);
 
-					atom.m_uds = KIO::UDS_MIME_TYPE;
+					atom.m_uds = TDEIO::UDS_MIME_TYPE;
 					atom.m_str = "application/sieve";
 					entry.append(atom);
 
@@ -937,22 +937,22 @@ void kio_sieveProtocol::listDir(const KURL& url)
 			entry.clear();
 
 			UDSAtom atom;
-			atom.m_uds = KIO::UDS_NAME;
+			atom.m_uds = TDEIO::UDS_NAME;
 			atom.m_str = TQString::fromUtf8(r.getKey());
 			entry.append(atom);
 
-			atom.m_uds = KIO::UDS_FILE_TYPE;
+			atom.m_uds = TDEIO::UDS_FILE_TYPE;
 			atom.m_long = S_IFREG;
 			entry.append(atom);
 
-			atom.m_uds = KIO::UDS_ACCESS;
+			atom.m_uds = TDEIO::UDS_ACCESS;
 			if ( r.getExtra() == "ACTIVE" )
 			  atom.m_long = 0700; // mark exec'able
 			else
 			  atom.m_long = 0600;
 			entry.append(atom);
 
-			atom.m_uds = KIO::UDS_MIME_TYPE;
+			atom.m_uds = TDEIO::UDS_MIME_TYPE;
 			atom.m_str = "application/sieve";
 			entry.append(atom);
 
@@ -441,7 +441,7 @@ void kio_sieveProtocol::disconnect(bool forcibly)
 		// This crashes under certain conditions as described in
 		// http://intevation.de/roundup/kolab/issue2442
-		// Fixing KIO::TCPSlaveBase::atEnd() for !fd would also work but 3.x is on life support.
+		// Fixing TDEIO::TCPSlaveBase::atEnd() for !fd would also work but 3.x is on life support.
 		//if (!operationSuccessful())
 		//	ksDebug() << "Server did not logout cleanly." << endl;
-- 
cgit v1.2.1